import { AxiosInstance, AxiosRequestConfig } from "axios";
interface Dict {
    [key: string]: string;
}
interface AuthConfig {
    uri: string;
    data: Record<string, unknown>;
    tokenKeys: string[];
}
interface AxiosFactoryConfig {
    name: string;
    auth: AuthConfig;
    headers?: Dict;
}
/**
 * AxiosFactory 类用于创建和配置 Axios 实例。
 * 处理登录认证并管理 cookies 和 tokens。
 */
declare class AxiosFactory {
    cookies: Map<string, string>;
    tokens: Dict;
    config: AxiosFactoryConfig;
    axiosClient: AxiosInstance;
    verified: boolean;
    maxCookies: number;
    retryDelays: number[];
    /**
     * 构造函数初始化 AxiosFactory。
     * @param config - AxiosFactory 的配置参数。
     * @param axiosConfig - Axios 的配置参数。
     * @param cache - 缓存配置（目前未使用）。
     */
    constructor(config: AxiosFactoryConfig, axiosConfig: AxiosRequestConfig, cache?: any);
    /**
     * 初始化方法，通过调用登录方法进行认证。
     */
    initialize(): Promise<void>;
    login(retryAttempt?: number): Promise<void>;
    /**
     * 创建 Axios 实例并设置拦截器。
     * @param axiosConfig - Axios 的配置参数。
     * @returns 创建的 Axios 实例。
     */
    createAxiosClient(axiosConfig: AxiosRequestConfig): AxiosInstance;
    /**
     * 设置请求和响应拦截器。
     * @param api - Axios 实例。
     */
    setupInterceptors(api: AxiosInstance): void;
}
export default AxiosFactory;
